## Datasets

```{eval-rst}
.. module:: scanpy.datasets
```

```{eval-rst}
.. currentmodule:: scanpy
```

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   datasets.blobs
   datasets.ebi_expression_atlas
   datasets.krumsiek11
   datasets.moignard15
   datasets.pbmc3k
   datasets.pbmc3k_processed
   datasets.pbmc68k_reduced
   datasets.paul15
   datasets.toggleswitch
   datasets.visium_sge

```
